==> kubernetes-model-policy-5.2.0-sources.jar: io/fabric8/kubernetes/api/model/policy/PodSecurityPolicyFluent.java <==
package io.fabric8.kubernetes.api.model.policy;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface PodSecurityPolicyFluent<A extends PodSecurityPolicyFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public PodSecurityPolicyFluent.MetadataNested<A> withNewMetadata();
    public PodSecurityPolicyFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public PodSecurityPolicyFluent.MetadataNested<A> editMetadata();
    public PodSecurityPolicyFluent.MetadataNested<A> editOrNewMetadata();
    public PodSecurityPolicyFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public PodSecurityPolicySpec getSpec();
    public PodSecurityPolicySpec buildSpec();
    public A withSpec(PodSecurityPolicySpec spec);
    public Boolean hasSpec();
    public PodSecurityPolicyFluent.SpecNested<A> withNewSpec();
    public PodSecurityPolicyFluent.SpecNested<A> withNewSpecLike(PodSecurityPolicySpec item);
    public PodSecurityPolicyFluent.SpecNested<A> editSpec();
    public PodSecurityPolicyFluent.SpecNested<A> editOrNewSpec();
    public PodSecurityPolicyFluent.SpecNested<A> editOrNewSpecLike(PodSecurityPolicySpec item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<PodSecurityPolicyFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodSecurityPolicySpecFluent<PodSecurityPolicyFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


}

==> kubernetes-model-policy-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/policy/PodSecurityPolicyFluent.java <==
package io.fabric8.kubernetes.api.model.policy;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface PodSecurityPolicyFluent<A extends PodSecurityPolicyFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public PodSecurityPolicyFluent.MetadataNested<A> withNewMetadata();
    public PodSecurityPolicyFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public PodSecurityPolicyFluent.MetadataNested<A> editMetadata();
    public PodSecurityPolicyFluent.MetadataNested<A> editOrNewMetadata();
    public PodSecurityPolicyFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public PodSecurityPolicySpec getSpec();
    public PodSecurityPolicySpec buildSpec();
    public A withSpec(PodSecurityPolicySpec spec);
    public Boolean hasSpec();
    public PodSecurityPolicyFluent.SpecNested<A> withNewSpec();
    public PodSecurityPolicyFluent.SpecNested<A> withNewSpecLike(PodSecurityPolicySpec item);
    public PodSecurityPolicyFluent.SpecNested<A> editSpec();
    public PodSecurityPolicyFluent.SpecNested<A> editOrNewSpec();
    public PodSecurityPolicyFluent.SpecNested<A> editOrNewSpecLike(PodSecurityPolicySpec item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<PodSecurityPolicyFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodSecurityPolicySpecFluent<PodSecurityPolicyFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


}
